pub fn sample_query() -> ContextQueryExpand description
The query the suite probes every provider with — no kinds filter, so any
provider is asked for its best frames (SPEC.md 5).
pub fn sample_query() -> ContextQueryThe query the suite probes every provider with — no kinds filter, so any
provider is asked for its best frames (SPEC.md 5).